@@ -4,12 +4,13 @@ Fake MakeMovieFrames and AssembleTestMovie
 from astropy.io import fits
 from dkist_processing_common.models.tags import Tag
 from dkist_processing_common.parsers.l1_fits_access import L1FitsAccess
-from dkist_processing_common.tasks import ScienceTaskL0ToL1Base
-from dkist_processing_common.tasks.assemble_movie import AssembleMovie
+from dkist_processing_common.tasks import AssembleMovie
+from dkist_processing_common.tasks import WorkflowTaskBase
+from dkist_processing_common.tasks.mixin.fits import FitsDataMixin
 from PIL import ImageDraw
 
 
-class MakeTestMovieFrames(ScienceTaskL0ToL1Base):
+class MakeTestMovieFrames(WorkflowTaskBase, FitsDataMixin):
     """
     Take each output frame, copy the header and data and write out
     as a movie frame
